from django.db import models
from model_utils.models import TimeStampedModel


class Country(TimeStampedModel):
    name = models.CharField(max_length=255)
    currency = models.ForeignKey("currency.Currency", on_delete=models.CASCADE)

    class Meta:
        db_table = "country"
        verbose_name_plural = "countries"

    def __str__(self):
        return self.name



from django.contrib import admin
from .models import Bank, AccountType, BankAccount


@admin.register(Bank)
class BankAdmin(admin.ModelAdmin):
    list_display = (
        "id",
        "name",
        "country",
        "is_active"
    )
    list_filter = ("is_active",)


@admin.register(AccountType)
class AccountTypeAdmin(admin.ModelAdmin):

    list_display = (
        "id",
        "name",
    )


@admin.register(BankAccount)
class BankAccountAdmin(admin.ModelAdmin):
    list_display = (
        "id",
        "bank",
        "account_number",
        "inter_account_number",
        "account_owner_name",
        "account_owner_id",
        "accounttype",
        "currency",
    )



# -*- coding: utf-8 -*-
from django.db import models
from model_utils.models import TimeStampedModel


class Bank(TimeStampedModel):
    name = models.CharField(
        max_length=45,
        help_text="bank name",
    )
    country = models.ForeignKey(
        "country.Country",
        on_delete=models.PROTECT,
    )
    account_types = models.ManyToManyField("bank.AccountType")
    is_active = models.BooleanField(default=True)

    class Meta:
        db_table = "bank"
        ordering = ["-created"]

    def __str__(self):
        return "{}, {}".format(self.name, self.country.name)


class AccountType(TimeStampedModel):
    name = models.CharField(
        max_length=45,
        help_text="name account type",
    )

    class Meta:
        db_table = "accounttype"
        ordering = ["-created"]

    def __str__(self):
        return self.name


class BankAccount(TimeStampedModel):
    account_number = models.CharField(
        max_length=45,
        blank=True,
        null=True,
    )
    inter_account_number = models.CharField(
        max_length=45,
        blank=True,
        null=True,
    )
    account_owner_name = models.CharField(
        max_length=200,
        blank=True,
        null=True,
    )
    account_owner_id = models.CharField(
        max_length=200,
        blank=True,
        null=True,
        help_text="Account owner id, could be RUC, VAT, etc"
    )
    bank = models.ForeignKey(
        "bank.Bank",
        on_delete=models.PROTECT,
        blank=True,
        null=True,
    )
    accounttype = models.ForeignKey(
        "bank.AccountType",
        on_delete=models.PROTECT,
        blank=True,
        null=True,
    )
    currency = models.ForeignKey(
        "currency.Currency",
        on_delete=models.PROTECT,
        blank=True,
        null=True,
    )
    
    class Meta:
        db_table = "bankaccount"
        ordering = ["-created"]



# Generated by Django 3.0.3 on 2020-03-13 15:16

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import model_utils.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('currency', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Country',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('name', models.CharField(max_length=255)),
                ('currency', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='currency.Currency')),
            ],
            options={
                'verbose_name_plural': 'countries',
                'db_table': 'country',
            },
        ),
    ]



# Generated by Django 3.0.3 on 2020-03-13 15:16

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import model_utils.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('currency', '0001_initial'),
        ('country', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='AccountType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('name', models.CharField(help_text='name account type', max_length=45)),
            ],
            options={
                'db_table': 'accounttype',
                'ordering': ['-created'],
            },
        ),
        migrations.CreateModel(
            name='Bank',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('name', models.CharField(help_text='bank name', max_length=45)),
                ('is_active', models.BooleanField(default=True)),
                ('account_types', models.ManyToManyField(to='bank.AccountType')),
                ('country', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='country.Country')),
            ],
            options={
                'db_table': 'bank',
                'ordering': ['-created'],
            },
        ),
        migrations.CreateModel(
            name='BankAccount',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('account_number', models.CharField(blank=True, max_length=45, null=True)),
                ('inter_account_number', models.CharField(blank=True, max_length=45, null=True)),
                ('account_owner_name', models.CharField(blank=True, max_length=200, null=True)),
                ('account_owner_id', models.CharField(blank=True, help_text='Account owner id, could be RUC, VAT, etc', max_length=200, null=True)),
                ('accounttype', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='bank.AccountType')),
                ('bank', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='bank.Bank')),
                ('currency', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='currency.Currency')),
            ],
            options={
                'db_table': 'bankaccount',
                'ordering': ['-created'],
            },
        ),
    ]



from django.db import models
from model_utils.models import TimeStampedModel


class Currency(TimeStampedModel):
    name = models.CharField(max_length=255)
    currency_symbol = models.CharField(max_length=3, blank=True)

    class Meta:
        db_table = "currency"
        verbose_name_plural = "currencies"

    def __str__(self):
        return self.name
